@@ -110,9 +110,15 @@ class S2(Pulse):
         
         returns array of floats (mean expectation) 
         """
+        sc_gain = resource.s2_correction_map(positions)
+        # depending on if you use the data driven or mc pattern map for light yield for S2 
+        # the shape of n_photon_hits will change. Mc needs a squeeze
+        if len(sc_gain.shape) != 1:
+            sc_gain=np.squeeze(sc_gain, axis=-1)
+
         # sc gain should has the unit of pe / electron, here we divide 1 + dpe to get nphoton / electron
-        sc_gain = resource.s2_correction_map(positions) \
-                * config['s2_secondary_sc_gain'] / (1 + config['p_double_pe_emision'])
+        sc_gain /= 1 + config['p_double_pe_emision']
+        sc_gain *= config['s2_secondary_sc_gain']
 
         # data driven map contains nan, will be set to 0 here
         sc_gain[np.isnan(sc_gain)] = 0
